<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>DialogAbout</name>
    <message>
        <location filename="../dialogabout.ui" line="14"/>
        <source>About IMSProg</source>
        <translation>IMSProg névjegye</translation>
    </message>
    <message>
        <source>IMSProg - free software I2C, SPI and MicroWire EEPROM/Flash chip programmer for CH341a devices. IMSProg supports 24Cxx, 25xx, 93Cxx, and M95xx series chips.</source>
        <translation type="vanished">IMSProg - ingyenes szoftver I2C, SPI és MicroWire EEPROM/Flash chip programozó CH341a eszközökhöz. Az IMSProg a 24Cxx, 25xx, 93Cxx és M95xx sorozatú chipeket támogatja.</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;In this program &lt;a href=&quot;https://github.com/Simsys/qhexedit2/&quot;&gt;QhexEditor2&lt;/a&gt; widget and modified programmer &lt;a href=&quot;https://github.com/McMCCRU/SNANDer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;SNANDer&lt;/span&gt;&lt;/a&gt; were used.&lt;/p&gt;&lt;p&gt;The page on GitHub is &lt;a href=&quot;https://github.com/bigbigmdm/IMSProg&quot;&gt;here&lt;/a&gt;, the support page is &lt;a href=&quot;https://antenna-dvb-t2.ru/IMSProg.php&quot;&gt;here&lt;/a&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ebben a programban &lt;a href=&quot;https://github.com/Simsys/qhexedit2/&quot;&gt;QhexEditor2&lt;/a&gt; widget és egy módosított programozó a &lt;a href=&quot;https://github.com/McMCCRU/SNANDer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;SNANDer&lt;/span&gt;&lt;/a&gt; van felhasználva.&lt;/p&gt;&lt;p&gt;Az oldala a GitHub-on &lt;a href=&quot;https://github.com/bigbigmdm/IMSProg&quot;&gt;itt található&lt;/a&gt;, a támogatási oldal &lt;a href=&quot;https://antenna-dvb-t2.ru/IMSProg.php&quot;&gt;pedig itt&lt;/a&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="120"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="130"/>
        <source>1.1.4</source>
        <translation>1.1.4</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="48"/>
        <source>OR</source>
        <translation>VAGY</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="26"/>
        <source>IMSProg - free software I2C, SPI and MicroWire EEPROM/Flash chip programmer for CH341a devices. IMSProg supports 24Cxx, 25xx, 93Cxx, AT45DBxx and M95xx series chips.</source>
        <translation>IMSProg - ingyenes szoftver I2C, SPI és MicroWire EEPROM/Flash chip programozó CH341a eszközökhöz. Az IMSProg a 24Cxx, 25xx, 93Cxx, AT45DBxx és M95xx sorozatú chipeket támogatja.</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="99"/>
        <source>Written by 2023 Mikhail Medvedev</source>
        <translation>2023 Mikhail Medvedev készítette</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="169"/>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
</context>
<context>
    <name>DialogInfo</name>
    <message>
        <location filename="../dialoginfo.ui" line="14"/>
        <source>Connection info:</source>
        <translation>Kapcsolat információ:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="36"/>
        <source>Slot:</source>
        <translation>Foglalat:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="43"/>
        <location filename="../dialoginfo.ui" line="61"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="54"/>
        <source>Adapter:</source>
        <translation>Adapter:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="106"/>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
</context>
<context>
    <name>DialogRP</name>
    <message>
        <location filename="../dialogrp.ui" line="20"/>
        <source>Load block from file</source>
        <translation>Blokk betöltése fájlból</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="33"/>
        <source>All values in HEX format!</source>
        <translation>Minden érték HEX formátumban!</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="48"/>
        <source>Start address:</source>
        <translation>Kezdőcím:</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="112"/>
        <source>Load</source>
        <translation>Betöltés</translation>
    </message>
</context>
<context>
    <name>DialogSFDP</name>
    <message>
        <location filename="../dialogsfdp.ui" line="14"/>
        <source>Information about SFDP and status registers</source>
        <translation>Információk az SFDP-ről és az állapotregiszterekről</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="47"/>
        <source>SFDP support:</source>
        <translation>SFDP támogatás:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="67"/>
        <source>Minimum VCC:</source>
        <translation>Minimális VCC:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="87"/>
        <source>Maximum VCC:</source>
        <translation>Maximális VCC:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="107"/>
        <source>Chip size:</source>
        <translation>Chip mérete:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="127"/>
        <source>Block size:</source>
        <translation>Blokkméret:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="150"/>
        <source>Speeds:</source>
        <translation>Sebességek:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="170"/>
        <source>OTP support:</source>
        <translation>OTP támogatás:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="196"/>
        <source>Status Register 0</source>
        <translation>Állapotregiszter 0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="424"/>
        <source>SPR0</source>
        <translation>SPR0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="449"/>
        <source>BP4</source>
        <translation>BP4</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="474"/>
        <source>BP3</source>
        <translation>BP3</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="499"/>
        <source>BP2</source>
        <translation>BP2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="524"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="549"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="574"/>
        <source>WEL</source>
        <translation>WEL</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="599"/>
        <source>WIP</source>
        <translation>WIP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="830"/>
        <source>SUS1</source>
        <translation>SUS1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="855"/>
        <source>CMP</source>
        <translation>CMP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="880"/>
        <source>LB3</source>
        <translation>LB3</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="905"/>
        <source>LB2</source>
        <translation>LB2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="930"/>
        <source>LB1</source>
        <translation>LB1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="955"/>
        <source>SUS2</source>
        <translation>SUS2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="980"/>
        <source>QE</source>
        <translation>QE</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1005"/>
        <source>SPR1</source>
        <translation>SPR1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="611"/>
        <source>Status Register 1</source>
        <translation>Állapotregiszter 1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1017"/>
        <source>Status register 2</source>
        <translation>Állapotregiszter 2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1195"/>
        <source>JEDEC info:</source>
        <translation>JEDEC infó:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1301"/>
        <source>Man. ID</source>
        <translatorcomment>Hers. Art</translatorcomment>
        <translation>Man. ID</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1323"/>
        <source>Man. type</source>
        <translation>Man. típus</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1345"/>
        <source>Capacity</source>
        <translation>Kapacitás</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1357"/>
        <source>Unique ID:</source>
        <translation>Egyedi ID:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1398"/>
        <source>Read</source>
        <translation>Olvasás</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1426"/>
        <source>Write registers</source>
        <translation>Írj regisztereket</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1453"/>
        <location filename="../dialogsfdp.ui" line="1519"/>
        <location filename="../dialogsfdp.ui" line="1541"/>
        <source>(R)</source>
        <translation>(R)</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1475"/>
        <source>DRV1</source>
        <translation>DRV1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1497"/>
        <source>DRV0</source>
        <translation>DRV0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1563"/>
        <source>WPS</source>
        <translation>WPS</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1585"/>
        <source>ADP</source>
        <translation>ADP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1607"/>
        <source>ADS</source>
        <translation>ADS</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1693"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p/&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p/&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1731"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Legend:&lt;/p&gt;&lt;p&gt;** - Basic area&lt;br&gt;** - Extended area&lt;br&gt;** - Manufacture area &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Jelmagyarázat:&lt;/p&gt;&lt;p&gt;** - Alapterület&lt;br&gt;** - Bővített terület&lt;br&gt;** - Gyártói terület &lt;/p&gt;&lt;/body &gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1776"/>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="79"/>
        <location filename="../dialogsfdp.cpp" line="99"/>
        <location filename="../dialogsfdp.cpp" line="208"/>
        <location filename="../dialogsfdp.cpp" line="228"/>
        <location filename="../dialogsfdp.cpp" line="254"/>
        <location filename="../dialogsfdp.cpp" line="283"/>
        <location filename="../dialogsfdp.cpp" line="298"/>
        <location filename="../dialogsfdp.cpp" line="415"/>
        <location filename="../dialogsfdp.cpp" line="417"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="99"/>
        <location filename="../dialogsfdp.cpp" line="208"/>
        <location filename="../dialogsfdp.cpp" line="228"/>
        <location filename="../dialogsfdp.cpp" line="254"/>
        <source>Error reading register!</source>
        <translation>Regiszter olvasás hiba!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="171"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Hex SFDP register data:
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Hex SFDP regiszter adata:
</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="172"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Addr:&lt;br&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Cłm:&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="417"/>
        <source>Before writing the registers, please press the `Read` button!</source>
        <translation>A névjegyzékek írása előtt kérjük, nyomja meg az `Olvasás` gombot!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="79"/>
        <source>Error reading JEDEC ID!</source>
        <translation>JEDEC ID olvasási hiba!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="39"/>
        <source>Legend:</source>
        <translation>Jelmagyarázat:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="40"/>
        <source> - Basic area</source>
        <translation> - Alapterület</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="41"/>
        <source> - Extended area</source>
        <translation> - Bővített terület</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="42"/>
        <source> - Manufacture area</source>
        <translation> - Gyártói terület</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="283"/>
        <source>Error reading unique ID!</source>
        <translation>Egyedi ID olvasási hiba!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="298"/>
        <location filename="../dialogsfdp.cpp" line="415"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>A CH341a programozó nincs csatlakoztatva!</translation>
    </message>
</context>
<context>
    <name>DialogSP</name>
    <message>
        <location filename="../dialogsp.ui" line="14"/>
        <source>Save part of image</source>
        <translation>Mentse el a kép egy részét</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="27"/>
        <source>All values in HEX format!</source>
        <translation>Minden érték HEX formátumban!</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="42"/>
        <source>Start address:</source>
        <translation>Kezdő cím:</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="120"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../dialogsp.cpp" line="27"/>
        <source>End address</source>
        <translation>Végcím</translation>
    </message>
    <message>
        <location filename="../dialogsp.cpp" line="28"/>
        <source>Length</source>
        <translation>Hosszúság</translation>
    </message>
</context>
<context>
    <name>DialogSR</name>
    <message>
        <location filename="../dialogsr.ui" line="14"/>
        <source>Status register</source>
        <translation>Állapotregiszter</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="296"/>
        <source>WPEN</source>
        <translation>WPEN</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="327"/>
        <location filename="../dialogsr.ui" line="358"/>
        <location filename="../dialogsr.ui" line="389"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="420"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="451"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="482"/>
        <source>WEN</source>
        <translation>WEN</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="513"/>
        <source>/RDY</source>
        <translation>/RDY</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="545"/>
        <source>Read</source>
        <translation>Olvasás</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="571"/>
        <source>Write</source>
        <translation>Írás</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="55"/>
        <location filename="../dialogsr.cpp" line="69"/>
        <location filename="../dialogsr.cpp" line="108"/>
        <location filename="../dialogsr.cpp" line="111"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="55"/>
        <source>Error reading register!</source>
        <translation>Regiszter olvasás hiba!</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="69"/>
        <location filename="../dialogsr.cpp" line="111"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>A CH341a programozó nincs csatlakoztatva!</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="108"/>
        <source>Before writing the register, please press the `Read` button!</source>
        <translation>A névjegyzékek írása előtt kérjük, nyomja meg az `Olvasás` gombot!</translation>
    </message>
</context>
<context>
    <name>DialogSecurity</name>
    <message>
        <location filename="../dialogsecurity.ui" line="14"/>
        <source>Security registers</source>
        <translation>Biztonsági regiszterek</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="24"/>
        <source>Hex Editor</source>
        <translation>Hexa szerkesztő</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="64"/>
        <source>Operations:</source>
        <translation>Műveletek:</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="93"/>
        <source>Reading security register data from the chip</source>
        <translation>Biztonsági regiszter adatok kiolvasása a chipről</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="96"/>
        <location filename="../dialogsecurity.ui" line="128"/>
        <location filename="../dialogsecurity.ui" line="160"/>
        <location filename="../dialogsecurity.ui" line="199"/>
        <location filename="../dialogsecurity.ui" line="231"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="125"/>
        <source>Erasing security register data</source>
        <translation>Biztonsági regiszter adatok törlése</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="157"/>
        <source>Writing data to the security register</source>
        <translation>Adatok írása a bitzonsági regiszterbe</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="196"/>
        <source>Open a binary file from a computer</source>
        <translation>Bináris fájlt megnyitása a számítógépről</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="228"/>
        <source>Save the binary file on the computer</source>
        <translation>Mentse el a bináris fájlt a számítógépére</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="257"/>
        <source>Security register number:</source>
        <translation>Biztonsági regiszter száma:</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="161"/>
        <location filename="../dialogsecurity.cpp" line="171"/>
        <location filename="../dialogsecurity.cpp" line="245"/>
        <location filename="../dialogsecurity.cpp" line="279"/>
        <location filename="../dialogsecurity.cpp" line="350"/>
        <location filename="../dialogsecurity.cpp" line="375"/>
        <location filename="../dialogsecurity.cpp" line="408"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="161"/>
        <source>Error reading register!</source>
        <translation>Regiszter olvasási hiba!</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="171"/>
        <location filename="../dialogsecurity.cpp" line="279"/>
        <location filename="../dialogsecurity.cpp" line="350"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>A CH341a programozó nincs csatlakoztatva!</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="245"/>
        <source>Error writing register!</source>
        <translation>Regiszter írási hiba!</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="366"/>
        <source>Open file</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="375"/>
        <source>The file size exceeds the security register size.</source>
        <translation>A fájl mérete meghaladja a biztonsági regiszter méretét.</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="397"/>
        <source>Save file</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="408"/>
        <source>Error saving file!</source>
        <translation>Hiba a fájl mentésekor!</translation>
    </message>
</context>
<context>
    <name>DialogSetAddr</name>
    <message>
        <location filename="../dialogsetaddr.ui" line="14"/>
        <source>Goto address</source>
        <translation>Goto cím</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="24"/>
        <source>All values in HEX format!</source>
        <translation>Minden érték HEX formátumban!</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="39"/>
        <source>Address:</source>
        <translation>Cím:</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="90"/>
        <source>Go to</source>
        <translation>Menjen a</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="928"/>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1021"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1024"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1045"/>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1048"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1033"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>IMSProg - I2C/MicroWire/SPI CH341a Programmer</source>
        <translation>IMSProg - I2C/MicroWire/SPI CH341a programozó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Chip</source>
        <translation>Chip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Page size</source>
        <translation>Oldalméret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <source>Block size</source>
        <translation>Blokkméret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>VCC, Volt</source>
        <translation>VCC, Volt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>4byte Addr.</source>
        <translation>4bájtos cím.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <location filename="../mainwindow.ui" line="1057"/>
        <source>Detect</source>
        <translation>Felismerés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Read</source>
        <translation>Olvasás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>i</source>
        <translation>i</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>I2C bus speed</source>
        <translation>I2C buszsebesség</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="612"/>
        <source>Auto Options</source>
        <translation>Automatikus opciók</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="629"/>
        <location filename="../mainwindow.ui" line="1081"/>
        <source>Erase</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="639"/>
        <source>Program</source>
        <translation>Program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="649"/>
        <location filename="../mainwindow.ui" line="1105"/>
        <source>Verify</source>
        <translation>Ellenőrzés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <source>Go!</source>
        <translation>Rajta!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <location filename="../mainwindow.ui" line="959"/>
        <source>Hex Editor</source>
        <translation>Hexa szerkesztő</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="805"/>
        <source>  JEDEC ID:</source>
        <translation>  JEDEC ID:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="821"/>
        <source>CH341a:</source>
        <translation>CH341a:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="846"/>
        <source>border: 2px solid gray;border-radius: 5px;font-weight:600;border-style:inset;</source>
        <translation>border: 2px solid gray;border-radius: 5px;font-weight:600;border-style:inset;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="859"/>
        <source>CRC32:</source>
        <translation>CRC32:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="946"/>
        <source>Programmer</source>
        <translation>Programozó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="969"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1036"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1060"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1072"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1084"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1093"/>
        <source>Write</source>
        <translation>Írás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1096"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1108"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1117"/>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1120"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1129"/>
        <source>Redo</source>
        <translation>Ismét</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1132"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1141"/>
        <source>Save Part</source>
        <translation>Részlet mentése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1153"/>
        <source>Load Part</source>
        <translation>Részlet betöltése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1165"/>
        <source>Find / Replace</source>
        <translation>Keresés / Csere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1168"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1173"/>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1176"/>
        <source>About IMSProgrammer</source>
        <translation>IMS Programozó névjegye</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1179"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1188"/>
        <source>Checksum calculate</source>
        <translation>Ellenőrző összeg kiszámítása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1191"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <source>Edit chips Database</source>
        <translation>Chip-adatbázis szerkesztése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1203"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1212"/>
        <location filename="../mainwindow.cpp" line="1639"/>
        <source>Stop</source>
        <translation>Megállítás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1215"/>
        <source>Forced stop of read, write, erase and verification operations</source>
        <translation>Az olvasási, írási, törlési és ellenőrzési műveletek kényszerített leállítása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1218"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Chip info</source>
        <translation>Chip infó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Information about SFDP and status registers</source>
        <translation>Információk az SFDP-ről és az állapotregiszterekről</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1242"/>
        <source>Import from Intel HEX</source>
        <translation>Importálás Intel HEX-ből</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1251"/>
        <source>Export to Intel HEX</source>
        <translation>Exportálás Intel HEX-be</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1260"/>
        <source>Extract from ASUS CAP</source>
        <translation>Kivonat az ASUS CAP-ból</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1269"/>
        <source>Goto address</source>
        <translation>Goto cím</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1272"/>
        <source>Move the cursor to the entered address</source>
        <translation>Mozgassa a kurzort a beírt címre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1275"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1284"/>
        <source>Security registers</source>
        <translation>Biztonsági regiszterek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1287"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="771"/>
        <location filename="../mainwindow.cpp" line="811"/>
        <location filename="../mainwindow.cpp" line="1286"/>
        <location filename="../mainwindow.cpp" line="2028"/>
        <location filename="../mainwindow.cpp" line="2096"/>
        <source>Current file: </source>
        <translation>Jelenlegi fájl: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Manufacture</source>
        <translation>Gyártó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1688"/>
        <source>Opening DAT file</source>
        <translation>DAT fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="239"/>
        <location filename="../mainwindow.cpp" line="265"/>
        <location filename="../mainwindow.cpp" line="266"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="305"/>
        <location filename="../mainwindow.cpp" line="580"/>
        <location filename="../mainwindow.cpp" line="596"/>
        <location filename="../mainwindow.cpp" line="615"/>
        <location filename="../mainwindow.cpp" line="662"/>
        <location filename="../mainwindow.cpp" line="713"/>
        <location filename="../mainwindow.cpp" line="779"/>
        <location filename="../mainwindow.cpp" line="815"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <location filename="../mainwindow.cpp" line="926"/>
        <location filename="../mainwindow.cpp" line="933"/>
        <location filename="../mainwindow.cpp" line="954"/>
        <location filename="../mainwindow.cpp" line="964"/>
        <location filename="../mainwindow.cpp" line="1150"/>
        <location filename="../mainwindow.cpp" line="1159"/>
        <location filename="../mainwindow.cpp" line="1165"/>
        <location filename="../mainwindow.cpp" line="1175"/>
        <location filename="../mainwindow.cpp" line="1199"/>
        <location filename="../mainwindow.cpp" line="1200"/>
        <location filename="../mainwindow.cpp" line="1214"/>
        <location filename="../mainwindow.cpp" line="1243"/>
        <location filename="../mainwindow.cpp" line="1267"/>
        <location filename="../mainwindow.cpp" line="1300"/>
        <location filename="../mainwindow.cpp" line="1547"/>
        <location filename="../mainwindow.cpp" line="1697"/>
        <location filename="../mainwindow.cpp" line="1851"/>
        <location filename="../mainwindow.cpp" line="1863"/>
        <location filename="../mainwindow.cpp" line="2115"/>
        <location filename="../mainwindow.cpp" line="2147"/>
        <location filename="../mainwindow.cpp" line="2165"/>
        <location filename="../mainwindow.cpp" line="2185"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1243"/>
        <source>The end address must be greater than the starting address.</source>
        <translation>A zárócímnek nagyobbnak kell lennie, mint a kezdőcím.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1547"/>
        <source>File &apos;IMSProg_editor&apos; not found!</source>
        <translation>Nem található `IMSProg_editor` fájl!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1697"/>
        <source>Error loading chip database file!</source>
        <translation>Hiba a chip adatbázis fájl betöltésekor!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1703"/>
        <source>Parsing DAT file</source>
        <translation>DAT fájl feldolgozása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <source>Reading data from </source>
        <translation>Adat olvasása innen </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <location filename="../mainwindow.cpp" line="1150"/>
        <source>Unsupported chip type!</source>
        <translation>Nem támogatott chip típus!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="596"/>
        <location filename="../mainwindow.cpp" line="926"/>
        <location filename="../mainwindow.cpp" line="964"/>
        <location filename="../mainwindow.cpp" line="1159"/>
        <location filename="../mainwindow.cpp" line="1214"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>A CH341a programozó nincs csatlakoztatva!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <location filename="../mainwindow.cpp" line="1165"/>
        <source>Error reading block </source>
        <translation>Blokk olvasási hiba </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <location filename="../mainwindow.cpp" line="954"/>
        <location filename="../mainwindow.cpp" line="1199"/>
        <source>Before reading from chip please press &apos;Detect&apos; button.</source>
        <translation>A chipről történő olvasás előtt nyomja meg az „Felismerés” gombot.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Please select the chip parameters - manufacture and chip name</source>
        <translation>Kérjük, válassza ki a chip paramétereit - a gyártást és a chip nevét</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>The chip is not connect or missing!</source>
        <translation>A chip nincs csatlakoztatva vagy hiányzik!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <location filename="../mainwindow.cpp" line="2020"/>
        <source>Saving file</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <location filename="../mainwindow.cpp" line="2022"/>
        <source>Save file</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <location filename="../mainwindow.cpp" line="1267"/>
        <source>Error saving file!</source>
        <translation>Hiba a fájl mentésekor!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>Erasing the </source>
        <translation>Törlése a(z) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <location filename="../mainwindow.cpp" line="662"/>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Error erasing sector </source>
        <translation>Hiba a szektor törlésekor </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <location filename="../mainwindow.cpp" line="805"/>
        <location filename="../mainwindow.cpp" line="2090"/>
        <source>Opening file</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="807"/>
        <location filename="../mainwindow.cpp" line="2092"/>
        <source>Open file</source>
        <translation>Fájlmegnyitás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="779"/>
        <location filename="../mainwindow.cpp" line="815"/>
        <source>The file size exceeds the chip size. Please select another chip or file or use `Save part` to split the file.</source>
        <translation>A fájl mérete meghaladja a chip méretét. Kérjük, válasszon egy másik chipet vagy fájlt, vagy használja a `Részlet mentése` lehetőséget a fájl felosztásához.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1851"/>
        <source>Before working with the security registers, click the &apos;Detect&apos; button</source>
        <translation>A biztonsági regiszterekkel való munka előtt kattintson az „Felismerés” gombra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1863"/>
        <source>There are no security registers in this chip or the current version of IMSProg does not support this algorithm.</source>
        <translation>Ebben a chipben nincsenek biztonsági regiszterek, vagy az IMSProg jelenlegi verziója nem támogatja ezt az algoritmust.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2115"/>
        <source>Not valid HEX format!</source>
        <translation>Nem érvényes HEX formátum!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2147"/>
        <source>The address is larger than the size of the chip!</source>
        <translation>A cím nagyobb, mint a chip mérete!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2165"/>
        <location filename="../mainwindow.cpp" line="2185"/>
        <source>Checksum error!</source>
        <translation>Checksum hiba!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>Writing data to </source>
        <translation>Adat írása ide </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="933"/>
        <source>Error writing sector </source>
        <translation>Hiba a szektor írásakor </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1120"/>
        <source>Veryfing data from </source>
        <translation>Adatok ellenőrzése innen </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>Error comparing data!
Address:   </source>
        <translation>Hiba az adatok összehasonlításakor!
Cím:   </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>
Buffer: </source>
        <translation>
Puffer: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>    Chip: </source>
        <translation>    Chip: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1200"/>
        <source>Please select the chip parameters - manufacture and chip name.</source>
        <translation>Kérjük, válassza ki a chip paramétereit - a gyártót és a chip nevét.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1209"/>
        <source>Ok!</source>
        <translation>Ok!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1209"/>
        <source>The operation was successful!</source>
        <translation>A művelet sikeres volt!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1255"/>
        <source>Saving block</source>
        <translation>Blokk mentése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1257"/>
        <source>Save block</source>
        <translation>Blokk mentése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1281"/>
        <source>Opening block</source>
        <translation>Blokk megnyitása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1283"/>
        <source>Open block</source>
        <translation>Blokkmegnyitás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1300"/>
        <source>The end address out of image size!</source>
        <translation>A zárócím túllépi a kép méretét!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1339"/>
        <source>Connected</source>
        <translation>Csatlakozva</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1344"/>
        <source>Not connected</source>
        <translation>Nincs kapcs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1639"/>
        <source>Operation aborted!</source>
        <translation>Művelet megszakítva!</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../searchdialog.ui" line="14"/>
        <source>QHexEdit - Find/Replace</source>
        <translation>QHexEdit - Keresés/Csere</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="26"/>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="33"/>
        <location filename="../searchdialog.ui" line="78"/>
        <source>Hex</source>
        <translation>Hexa</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="38"/>
        <location filename="../searchdialog.ui" line="83"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="71"/>
        <source>Replace</source>
        <translation>Csere</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="116"/>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="122"/>
        <source>&amp;Backwards</source>
        <translation>&amp;Visszafelé</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="129"/>
        <source>&amp;Prompt on replace</source>
        <translation>Me&amp;gerősítés kérése minden csere előtt</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="150"/>
        <source>Standard headers:</source>
        <translation>Alapértelmezett fejlécek:</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="191"/>
        <source>ZIP</source>
        <translation>ZIP</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="213"/>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="235"/>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="257"/>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="286"/>
        <source>TAR</source>
        <translation>TAR</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="308"/>
        <source>UEFI</source>
        <translation>UEFI</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="330"/>
        <source>BIOS</source>
        <translation>BIOS</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="352"/>
        <source>GPT</source>
        <translation>GPT</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="385"/>
        <source>&amp;Find</source>
        <translation>&amp;Keresés</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="388"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="413"/>
        <source>&amp;Replace</source>
        <translation>&amp;Csere</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="435"/>
        <source>Replace &amp;All</source>
        <translation>Cserélje m&amp;indet</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="457"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="87"/>
        <location filename="../searchdialog.cpp" line="113"/>
        <source>QHexEdit</source>
        <translation>QHexEdit</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="87"/>
        <source>%1 occurrences replaced.</source>
        <translation>%1 előfordulás lecserélve.</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="114"/>
        <source>Replace occurrence?</source>
        <translation>Előfordulás cseréje?</translation>
    </message>
</context>
<context>
    <name>UndoStack</name>
    <message>
        <location filename="../commands.cpp" line="130"/>
        <source>Inserting %1 bytes</source>
        <translation>%1 bájt beszúrása</translation>
    </message>
    <message>
        <location filename="../commands.cpp" line="152"/>
        <source>Delete %1 chars</source>
        <translation>%1 karakter törlése</translation>
    </message>
    <message>
        <location filename="../commands.cpp" line="177"/>
        <source>Overwrite %1 chars</source>
        <translation>%1 karakter felülírása</translation>
    </message>
</context>
</TS>
